
#line 3 "scannerlexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 1
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yynoreturn yy_fatal_error (yyconst char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 140
#define YY_END_OF_BUFFER 141
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[856] =
    {   0,
      141,  139,  140,    3,  139,  140,    1,  140,   35,  139,
      140,  139,  140,   10,  139,  140,   30,  139,  140,   32,
      139,  140,  139,  140,   19,  139,  140,   20,  139,  140,
       28,  139,  140,   26,  139,  140,   59,  139,  140,   27,
      139,  140,   25,  139,  140,   29,  139,  140,  132,  139,
      140,  132,  139,  140,   22,  139,  140,   21,  139,  140,
       37,  139,  140,   36,  139,  140,   38,  139,  140,   24,
      139,  140,   88,  129,  139,  140,   88,  129,  139,  140,
       15,  139,  140,  139,  140,   17,  139,  140,   31,  139,
      140,   88,  129,  139,  140,   88,  129,  139,  140,   88,

      129,  139,  140,   88,  129,  139,  140,   88,  129,  139,
      140,   88,  129,  139,  140,   88,  129,  139,  140,   88,
      129,  139,  140,   88,  129,  139,  140,   88,  129,  139,
      140,   88,  129,  139,  140,   88,  129,  139,  140,   88,
      129,  139,  140,   88,  129,  139,  140,   88,  129,  139,
      140,   88,  129,  139,  140,   11,  139,  140,   33,  139,
      140,   13,  139,  140,   34,  139,  140,    3,    1,   52,
      137,   43,   14,   55,   45,  135,   41,   57,   39,   58,
       40,   60,  133,    4,    5,   42,  133,  131,  132,  132,
      132,  132,   18,   12,   16,   47,   53,   51,   54,   48,

       88,  129,    2,   44,   88,  129,   88,  129,   88,  129,
       88,  129,   88,  129,   88,  129,   88,  129,   88,  129,
       88,  129,   88,  129,   88,  129,   88,   98,  129,   88,
      129,   88,  129,   88,  129,   88,  129,   88,  129,   88,
      129,   88,  106,  129,   88,  129,   88,  129,   88,  129,
       88,  129,   88,  129,   88,  129,   88,  129,   88,  129,
       88,  129,   88,  129,   88,  129,   46,   56,   23,  133,
        5,  131,  132,  131,  132,  134,  132,  132,  132,  130,
       49,   50,  138,  136,   88,  129,   88,  129,   88,  129,
       88,  129,   88,  129,   88,  129,   88,  129,   88,  129,

       88,  129,   88,  129,   88,  129,   88,  129,   88,  129,
       88,  129,   88,   89,  129,   88,  129,   88,  129,   88,
      129,   88,  129,   88,  129,   88,  129,   88,  129,   88,
      129,   88,  129,   88,  129,   88,  129,   88,  129,   88,
      104,  129,   88,  129,   88,  129,   88,  108,  129,   88,
      129,   88,  129,   88,  129,   88,  129,   88,  129,   88,
      129,   88,  129,   88,  129,   88,  129,   88,  129,   88,
      129,   88,  129,   88,  129,   88,  129,   88,  129,   88,
      129,  133,  131,  132,  131,  132,  131,  132,  134,  132,
      130,  130,   88,  129,   88,  129,   88,  129,   88,  129,

       88,  129,   88,  129,   88,  129,   88,  129,   88,  129,
       88,  129,   88,  129,   88,  129,   88,  129,   88,  129,
       88,  129,   88,  129,   88,  129,   88,   90,  129,   88,
       91,  129,   88,  129,   88,   93,  129,   88,   94,  129,
       88,  129,   88,  129,   88,  129,   88,  129,   88,  100,
      129,   88,  101,  129,   88,  129,   88,  129,   88,  105,
      129,   88,  129,   88,  113,  129,   88,  129,   88,  129,
       88,  129,   88,  129,   88,  129,   88,  129,   88,  129,
       88,  129,   88,  129,   88,  129,   88,  129,   88,  129,
       88,  126,  129,   88,  129,   88,  129,    8,  131,  132,

      130,  130,  130,   80,   88,  129,   88,  129,   64,   88,
      129,   88,  129,   88,  129,   88,  129,   88,  129,   88,
      129,   88,  129,   88,  129,   88,  129,   88,  129,   88,
      129,   88,  129,   88,  129,   88,  129,   88,  129,   86,
       88,  129,   88,   92,  129,   88,   95,  129,   88,  129,
       88,  129,   88,  129,   88,  129,   88,  103,  129,   88,
      129,   88,  129,   88,  129,   88,  129,   88,  117,  129,
       88,  129,   88,  129,   88,  129,   88,  129,   88,  129,
       88,  129,   88,  124,  129,   88,  129,   88,  129,   88,
      128,  129,  130,   88,  129,   88,  129,   88,  129,   88,

      129,   88,  129,   88,  129,   88,  129,   88,  129,   88,
      129,   88,  129,   88,  129,   88,  129,   88,  129,   88,
      129,   88,  129,   88,  129,   88,  129,   88,  129,   88,
      129,   88,   99,  129,   88,  102,  129,   88,  107,  129,
       88,  129,   88,  129,   88,  116,  129,   88,  118,  129,
       88,  119,  129,   88,  120,  129,   88,  121,  129,   88,
      122,  129,   88,  129,   88,  129,   88,  129,   88,  129,
       65,   88,  129,   88,  129,   82,   88,  129,   68,   88,
      129,   88,  129,   88,  129,   88,  129,   88,  129,   87,
       88,  129,   88,  129,   88,  129,   88,  129,   88,  129,

       88,  129,   88,  129,   88,  129,   88,  129,   88,   97,
      129,   88,  129,   88,  129,   88,  123,  129,   88,  129,
       88,  129,   88,  129,   88,  129,   88,  129,   88,  129,
       71,   88,  129,   88,  112,  129,   88,  129,   88,  129,
       88,  129,   88,  129,   77,   88,  129,   88,  129,   88,
      129,   88,   96,  129,   88,  114,  129,   88,  115,  129,
       88,  125,  129,   88,  127,  129,    7,    9,   73,   88,
      129,   88,  129,   88,  129,   88,  129,   88,  129,   88,
      129,   72,   88,  129,   88,  129,   88,  129,   85,   88,
      129,   88,  111,  129,   88,  129,    6,    7,   88,  129,

       88,  129,   88,  129,   70,   88,  129,   88,  110,  129,
       75,   88,  129,   74,   88,  129,   88,  129,   78,   88,
      129,   67,   88,  129,   88,  129,   88,  129,   88,  109,
      129,   88,  129,   88,  129,   88,  129,   76,   88,  129,
       79,   88,  129,   66,   88,  129,   84,   69,   88,  129,
       61,   62,   63,   83,   81
    } ;

static yyconst flex_int16_t yy_accept[507] =
    {   0,
        1,    1,    1,    2,    4,    7,    9,   12,   14,   17,
       20,   23,   25,   28,   31,   34,   37,   40,   43,   46,
       49,   52,   55,   58,   61,   64,   67,   70,   73,   77,
       81,   84,   86,   89,   92,   96,  100,  104,  108,  112,
      116,  120,  124,  128,  132,  136,  140,  144,  148,  152,
      156,  159,  162,  165,  168,  169,  170,  171,  171,  172,
      172,  172,  172,  172,  173,  174,  175,  176,  176,  177,
      177,  178,  179,  180,  181,  182,  183,  183,  184,  185,
      186,  187,  188,  190,  191,  191,  192,  193,  193,  194,
      195,  196,  197,  198,  199,  200,  201,  203,  203,  203,

      204,  205,  207,  209,  211,  213,  215,  217,  219,  221,
      223,  225,  227,  230,  232,  234,  236,  238,  240,  242,
      245,  247,  249,  251,  253,  255,  257,  259,  261,  263,
      265,  267,  268,  269,  269,  269,  269,  270,  270,  271,
      272,  274,  276,  276,  277,  278,  279,  280,  281,  282,
      283,  283,  284,  284,  284,  285,  285,  287,  289,  291,
      293,  295,  297,  299,  301,  303,  305,  307,  309,  311,
      313,  316,  318,  320,  322,  324,  326,  328,  330,  332,
      334,  336,  338,  340,  343,  345,  347,  350,  352,  354,
      356,  358,  360,  362,  364,  366,  368,  370,  372,  374,

      376,  378,  380,  382,  382,  382,  382,  382,  383,  385,
      387,  389,  390,  391,  392,  393,  395,  397,  399,  401,
      403,  405,  407,  409,  411,  413,  415,  417,  419,  421,
      423,  425,  427,  430,  433,  435,  438,  441,  443,  445,
      447,  449,  452,  455,  457,  459,  462,  464,  467,  469,
      471,  473,  475,  477,  479,  481,  483,  485,  487,  489,
      491,  494,  496,  498,  498,  499,  499,  499,  501,  502,
      503,  504,  507,  509,  512,  514,  516,  518,  520,  522,
      524,  526,  528,  530,  532,  534,  536,  538,  540,  543,
      546,  549,  551,  553,  555,  557,  560,  562,  564,  566,

      568,  571,  573,  575,  577,  579,  581,  583,  586,  588,
      590,  593,  593,  593,  594,  596,  596,  598,  600,  602,
      604,  606,  608,  610,  612,  614,  616,  618,  620,  622,
      624,  626,  628,  630,  632,  635,  638,  641,  643,  645,
      648,  651,  654,  657,  660,  663,  665,  667,  669,  669,
      669,  671,  671,  674,  676,  679,  682,  684,  686,  688,
      690,  693,  695,  697,  699,  701,  703,  705,  707,  709,
      712,  714,  716,  719,  721,  723,  723,  723,  725,  725,
      725,  727,  729,  731,  734,  737,  739,  741,  743,  745,
      748,  750,  752,  755,  758,  761,  761,  764,  767,  768,

      768,  769,  772,  772,  772,  772,  774,  776,  778,  780,
      782,  785,  787,  789,  792,  795,  797,  797,  798,  799,
      799,  799,  799,  801,  803,  805,  808,  811,  814,  817,
      819,  822,  822,  822,  822,  822,  825,  825,  825,  827,
      829,  832,  834,  834,  834,  834,  834,  836,  836,  836,
      836,  838,  841,  844,  844,  844,  844,  844,  847,  848,
      848,  851,  851,  852,  852,  852,  852,  852,  852,  852,
      852,  852,  852,  853,  853,  853,  853,  853,  853,  853,
      853,  853,  853,  853,  853,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  855,  855,  855,  855,  855,

      855,  855,  855,  855,  856,  856
    } ;

static yyconst YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    8,    1,    9,   10,   11,   12,
       13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
       23,   24,   23,   25,   23,   26,   27,   28,   29,   30,
       31,   32,   33,    1,   34,   35,   34,   34,   36,   37,
       38,   38,   38,   38,   38,   39,   38,   40,   38,   38,
       38,   38,   38,   38,   41,   38,   38,   42,   38,   38,
       43,   44,   45,   46,   47,    1,   48,   49,   50,   51,

       52,   53,   54,   55,   56,   57,   58,   59,   60,   61,
       62,   63,   57,   64,   65,   66,   67,   68,   69,   70,
       71,   72,   73,   74,   75,   76,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst YY_CHAR yy_meta[77] =
    {   0,
        1,    2,    3,    1,    2,    1,    1,    1,    1,    1,
        1,    4,    1,    1,    1,    1,    1,    1,    1,    5,
        5,    5,    5,    5,    5,    5,    5,    1,    1,    1,
        1,    1,    1,    6,    6,    6,    7,    8,    9,    8,
        8,    8,    1,    1,    1,    1,    8,   10,   10,   10,
       10,   10,   11,   12,   12,   12,   12,   12,   13,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,    1,    1,    1,    1
    } ;

static yyconst flex_uint16_t yy_base[523] =
    {   0,
        0,    0,  869,  870,   75,    0,  837,   71,   76,   51,
       74,   74,  870,  870,  836,   71,  870,   72,   70,   92,
      118,  171,  834,  870,   89,  834,   68,  870,    0,  101,
      870,  861,  870,  832,   74,   57,   64,  100,   85,   91,
       48,  800,   72,  799,  808,  109,  788,  797,  795,  801,
      870,   56,  870,  870,  127,    0,  870,  109,  870,  852,
      179,  802,  797,  870,  870,  870,  870,   90,  870,  849,
      870,  870,  870,  870,  870,  870,  833,  219,  870,    0,
      870,    0,  190,    0,  194,  117,  107,    0,  870,  870,
      870,  819,  870,  870,  870,  818,    0,  142,  169,  870,

      870,  786,  785,  231,  786,  779,  782,  791,  777,  793,
      779,  786,  771,  772,  769,  769,  772,  769,  766,    0,
      108,  770,  117,  768,   97,  115,  773,  765,  116,  131,
      771,  870,  870,  242,  773,  764,  870,  286,  870,    0,
      194,  169,  294,  285,  181,  870,  195,  235,  870,  870,
      229,  870,  821,  215,  870,  820,  760,  757,  159,  224,
      768,  749,  757,  755,  764,  171,  744,  758,  751,  787,
        0,  749,  751,  761,  756,  743,  185,  758,  756,  752,
      743,  750,  753,    0,  738,  743,    0,  744,  741,  730,
      728,  730,  732,  740,  725,  723,  723,  736,  725,  730,

      734,  736,  724,  779,  725,  728,  305,  296,  293,  870,
      231,  870,  870,  298,  245,  720,  726,  717,  710,  723,
      713,  723,  706,  277,  710,  705,  715,  717,  704,  705,
      706,  740,    0,    0,  705,    0,    0,  696,  705,  693,
      700,    0,    0,  694,  691,    0,  695,    0,  690,  690,
      689,  686,  699,  688,  693,  698,  697,  695,  684,  690,
        0,  677,  690,  738,  870,  679,  734,  870,  299,  870,
      246,    0,  672,  343,  673,  686,  670,  675,  681,  676,
      268,  670,  664,  668,  678,  675,  660,  677,    0,    0,
        0,  663,  664,  670,  660,    0,  668,  653,  662,  656,

        0,  665,  662,  664,  647,  657,  659,    0,  649,  653,
        0,  656,  347,  870,  640,  348,  659,  649,  645,  637,
      637,  640,  639,  677,  674,  630,  632,  643,  646,  631,
      671,  625,  623,  623,    0,    0,    0,  636,  637,    0,
        0,    0,    0,    0,    0,  633,  633,  625,  678,  356,
      618,  619,  354,  631,    0,    0,  616,  613,  625,  650,
        0,  616,  618,  622,  613,  618,  648,  613,  616,    0,
      603,  600,  660,  613,  611,    0,  659,  600,  601,  382,
      592,  606,  601,  609,  608,  595,  603,  605,  592,    0,
      624,  590,    0,    0,    0,  598,    0,    0,  635,  643,

      870,    0,  597,  574,  552,  547,  562,  549,  563,  543,
        0,  542,  527,    0,  525,  518,  513,  870,  540,  484,
      480,  487,  464,  383,  454,    0,    0,  454,    0,  387,
      402,  400,  391,  384,  397,  397,  387,  392,  395,  394,
        0,  393,  375,  379,  378,  370,  388,    0,  421,  239,
      386,    0,    0,  426,  378,  380,  371,    0,  870,  328,
        0,  379,  870,  359,  365,  329,  376,  366,  369,  310,
      355,  360,  870,  350,  352,  365,  362,  367,  367,  338,
      347,  365,  351,  355,  870,  381,  359,  384,  361,  394,
      358,  392,  389,  336,  385,  289,  294,  224,  214,  230,

      107,  165,  110,  870,  870,  450,  463,  476,  485,  498,
      507,  518,  531,  540,  553,  562,  570,  583,  593,  605,
      618,  631
    } ;

static yyconst flex_int16_t yy_def[523] =
    {   0,
      505,    1,  505,  505,  505,  506,  505,  507,  505,  505,
      505,  508,  505,  505,  505,  505,  505,  505,  505,  505,
      505,  505,  505,  505,  505,  505,  505,  505,  509,  509,
      505,  505,  505,  505,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      505,  505,  505,  505,  505,  506,  505,  507,  505,  507,
      505,  505,  505,  505,  505,  505,  505,  508,  505,  508,
      505,  505,  505,  505,  505,  505,  505,  505,  505,  510,
      505,   78,   21,   22,  505,  505,  505,  511,  505,  505,
      505,  505,  505,  505,  505,  505,  509,  512,  513,  505,

      505,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  505,  505,  505,  505,  505,  505,  505,  505,  510,
      505,  505,  505,  514,  505,  505,  505,  511,  505,  505,
      512,  505,  512,  513,  505,  513,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,

      509,  509,  509,  515,  505,  505,  505,  516,  505,  505,
      505,  505,  505,  505,  505,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  515,  505,  505,  505,  505,  505,  505,
      505,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,

      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  505,  505,  505,  509,  505,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  505,  505,
      509,  505,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  517,  518,  509,  505,  505,
      509,  509,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  505,  509,  509,  519,  518,

      505,  509,  505,  505,  505,  509,  509,  509,  509,  509,
      509,  509,  509,  509,  509,  509,  505,  505,  519,  505,
      505,  505,  509,  509,  509,  509,  509,  509,  509,  509,
      509,  505,  505,  505,  505,  509,  505,  520,  509,  509,
      509,  509,  505,  505,  505,  505,  509,  520,  520,  520,
      509,  509,  509,  505,  505,  505,  505,  509,  505,  520,
      509,  505,  505,  505,  505,  520,  505,  505,  505,  520,
      505,  505,  505,  520,  505,  505,  520,  505,  505,  520,
      505,  505,  520,  505,  505,  520,  505,  520,  505,  521,
      505,  521,  521,  505,  521,  505,  505,  505,  505,  505,

      505,  522,  522,  505,    0,  505,  505,  505,  505,  505,
      505,  505,  505,  505,  505,  505,  505,  505,  505,  505,
      505,  505
    } ;

static yyconst flex_uint16_t yy_nxt[947] =
    {   0,
        4,    5,    6,    5,    5,    7,    8,    9,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
       22,   22,   22,   22,   22,   22,   22,   23,   24,   25,
       26,   27,   28,   29,   29,   29,   29,   29,   30,   29,
       29,   29,   31,   32,   33,   34,   35,   36,   37,   38,
       39,   40,   41,   42,   29,   43,   29,   29,   44,   29,
       29,   29,   29,   45,   46,   47,   48,   49,   50,   29,
       29,   29,   51,   52,   53,   54,   55,   59,   55,   55,
       61,   64,   65,   66,   69,   72,  132,   77,   74,   78,
       78,   78,   78,   78,   78,   78,   78,   90,   95,   96,

       69,   73,   75,   76,   67,   79,  117,   98,  102,  118,
       80,   99,  504,  103,   60,   59,   91,   70,   92,   93,
      104,  105,   81,  106,  120,  107,   62,  108,   55,  133,
       55,   55,  121,   70,   63,   82,  112,   83,   83,   83,
       83,   83,   83,   84,   84,  147,  113,  109,  152,  114,
      193,  115,   60,   85,  110,  145,   86,  146,   87,   88,
      116,  111,  195,  124,  125,  147,  186,  504,  194,   85,
      189,  199,  502,  187,  126,  145,   86,  127,  196,  155,
      200,  190,  191,  146,   87,  153,  201,   88,   82,  202,
       84,   84,   84,   84,   84,   84,   84,   84,  134,  134,

      134,  134,  134,  134,  134,  134,   85,  211,  143,   86,
      143,   87,  156,  144,  144,  144,  144,  144,  144,  144,
      144,  146,   85,  218,  219,  155,  227,  211,  141,   86,
      142,  505,  209,  213,  210,  152,  228,   87,   78,   78,
       78,   78,   78,   78,   78,   78,  204,  146,  141,  238,
      239,  459,  209,  213,  138,  139,  142,  139,  156,  505,
      210,  134,  134,  134,  134,  134,  134,  134,  134,  268,
      138,  139,  153,  214,  220,  215,  501,  139,  159,  500,
      160,  161,  162,  271,  314,  221,  163,  499,  324,  268,
      460,  164,  325,  214,  165,  166,  167,  168,  169,  170,

      207,  215,  207,  271,  314,  208,  208,  208,  208,  208,
      208,  208,  208,  144,  144,  144,  144,  144,  144,  144,
      144,  212,  459,  212,  208,  208,  208,  208,  208,  208,
      208,  208,  139,  210,  139,  280,  269,  212,  270,  270,
      459,  459,  281,  212,  316,  498,  316,  316,  139,  316,
      459,  316,  316,  497,  139,  380,  269,  380,  380,  210,
      377,  474,  459,  459,  270,  270,  350,  350,  350,  350,
      350,  350,  350,  350,  459,  350,  350,  350,  350,  350,
      350,  350,  350,  380,  437,  380,  380,  437,  437,  317,
      466,  437,  470,  459,  438,  490,  459,  495,  448,  477,

      496,  495,  486,  483,  493,  494,  493,  491,  489,  480,
      487,  485,  484,  482,  481,  352,  479,  478,  476,  475,
      473,  472,  471,  469,  468,  467,  465,  464,  404,  463,
      462,  488,  461,  459,  458,  457,  456,  455,  454,  453,
      452,  451,  450,  447,  446,  445,  444,  443,  442,  405,
       56,   56,  441,   56,   56,   56,   56,   56,   56,   56,
       56,   56,   56,   58,   58,   58,   58,   58,   58,   58,
       58,   58,   58,   58,   58,   58,   68,   68,   68,   68,
       68,   68,   68,   68,   68,   68,   68,   68,   68,   97,
       97,   97,   97,   97,   97,   97,   97,   97,  140,  140,

      440,  140,  140,  140,  140,  140,  140,  140,  140,  140,
      140,  148,  148,  148,  439,  436,  148,  148,  151,  151,
      151,  151,  151,  151,  151,  151,  151,  151,  151,  151,
      151,  154,  154,  154,  154,  154,  154,  154,  154,  154,
      154,  154,  154,  154,  144,  435,  144,  434,  144,  433,
      144,  418,  144,  264,  264,  264,  264,  264,  264,  264,
      264,  264,  264,  264,  264,  264,  208,  432,  208,  431,
      208,  430,  208,  429,  208,  399,  399,  399,  399,  399,
      399,  399,  399,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  419,  419,  419,  419,

      419,  419,  419,  419,  419,  419,  449,  428,  427,  426,
      425,  424,  423,  422,  449,  449,  449,  449,  492,  492,
      421,  492,  492,  492,  492,  492,  492,  492,  492,  492,
      492,  503,  503,  503,  503,  503,  503,  503,  503,  503,
      503,  503,  503,  503,  420,  401,  418,  417,  416,  415,
      414,  413,  412,  411,  410,  409,  408,  407,  406,  403,
      402,  401,  398,  397,  396,  395,  394,  393,  392,  391,
      390,  389,  388,  387,  386,  385,  384,  383,  382,  381,
      379,  378,  376,  375,  374,  373,  372,  371,  370,  369,
      368,  367,  366,  365,  364,  363,  362,  361,  360,  359,

      358,  357,  356,  355,  354,  353,  351,  349,  348,  347,
      346,  345,  344,  343,  342,  341,  340,  339,  338,  337,
      336,  335,  334,  333,  332,  331,  330,  329,  328,  327,
      326,  323,  322,  321,  320,  319,  318,  315,  313,  312,
      265,  311,  310,  309,  308,  307,  306,  305,  304,  303,
      302,  301,  300,  299,  298,  297,  296,  295,  294,  293,
      292,  291,  290,  289,  288,  287,  286,  285,  284,  283,
      282,  279,  278,  277,  276,  275,  274,  273,  272,  267,
      266,  265,  263,  262,  261,  260,  259,  258,  257,  256,
      255,  254,  253,  252,  251,  250,  249,  248,  247,  246,

      245,  244,  243,  242,  241,  240,  237,  236,  235,  234,
      233,  232,  231,  230,  229,  226,  225,  224,  223,  222,
      217,  216,  505,  505,  206,  205,  203,  198,  197,  192,
      188,  185,  184,  183,  182,  181,  180,  179,  178,  177,
      176,  175,  174,  173,  172,  171,  158,  157,  150,  149,
      137,  505,  136,  135,  505,  131,  130,  129,  128,  123,
      122,  119,  101,  100,   94,   89,   71,   57,  505,    3,
      505,  505,  505,  505,  505,  505,  505,  505,  505,  505,
      505,  505,  505,  505,  505,  505,  505,  505,  505,  505,
      505,  505,  505,  505,  505,  505,  505,  505,  505,  505,

      505,  505,  505,  505,  505,  505,  505,  505,  505,  505,
      505,  505,  505,  505,  505,  505,  505,  505,  505,  505,
      505,  505,  505,  505,  505,  505,  505,  505,  505,  505,
      505,  505,  505,  505,  505,  505,  505,  505,  505,  505,
      505,  505,  505,  505,  505,  505
    } ;

static yyconst flex_int16_t yy_chk[947] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    5,    8,    5,    5,
        9,   10,   10,   11,   12,   16,   52,   19,   18,   19,
       19,   19,   19,   19,   19,   19,   19,   25,   27,   27,

       68,   16,   18,   18,   11,   20,   41,   30,   35,   41,
       20,   30,  503,   35,    8,   58,   25,   12,   25,   25,
       35,   36,   20,   36,   43,   37,    9,   37,   55,   52,
       55,   55,   43,   68,    9,   21,   39,   21,   21,   21,
       21,   21,   21,   21,   21,   87,   39,   38,   98,   40,
      125,   40,   58,   21,   38,   86,   21,   86,   21,   21,
       40,   38,  126,   46,   46,   87,  121,  502,  125,   21,
      123,  129,  501,  121,   46,   86,   21,   46,  126,   99,
      129,  123,  123,   86,   21,   98,  130,   21,   22,  130,
       22,   22,   22,   22,   22,   22,   22,   22,   61,   61,

       61,   61,   61,   61,   61,   61,   22,  142,   85,   22,
       85,   22,   99,   85,   85,   85,   85,   85,   85,   85,
       85,  145,   22,  159,  159,  154,  166,  142,   83,   22,
       83,   83,  141,  147,  141,  151,  166,   22,   78,   78,
       78,   78,   78,   78,   78,   78,  134,  145,   83,  177,
      177,  450,  141,  147,   78,   78,   83,   78,  154,   83,
      141,  134,  134,  134,  134,  134,  134,  134,  134,  211,
       78,   78,  151,  148,  160,  148,  500,   78,  104,  499,
      104,  104,  104,  215,  271,  160,  104,  498,  281,  211,
      450,  104,  281,  148,  104,  104,  104,  104,  104,  104,

      138,  148,  138,  215,  271,  138,  138,  138,  138,  138,
      138,  138,  138,  143,  143,  143,  143,  143,  143,  143,
      143,  144,  470,  144,  207,  207,  207,  207,  207,  207,
      207,  207,  208,  209,  208,  224,  214,  144,  214,  269,
      460,  466,  224,  144,  274,  497,  274,  274,  208,  316,
      480,  316,  316,  496,  208,  353,  214,  353,  353,  209,
      350,  470,  474,  483,  214,  269,  313,  313,  313,  313,
      313,  313,  313,  313,  477,  350,  350,  350,  350,  350,
      350,  350,  350,  380,  424,  380,  380,  424,  437,  274,
      460,  437,  466,  486,  424,  488,  488,  495,  437,  474,

      494,  493,  483,  480,  492,  491,  490,  489,  487,  477,
      484,  482,  481,  479,  478,  316,  476,  475,  472,  471,
      469,  468,  467,  465,  464,  462,  457,  456,  380,  455,
      454,  486,  451,  449,  447,  446,  445,  444,  443,  442,
      440,  439,  438,  436,  435,  434,  433,  432,  431,  380,
      506,  506,  430,  506,  506,  506,  506,  506,  506,  506,
      506,  506,  506,  507,  507,  507,  507,  507,  507,  507,
      507,  507,  507,  507,  507,  507,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  509,
      509,  509,  509,  509,  509,  509,  509,  509,  510,  510,

      428,  510,  510,  510,  510,  510,  510,  510,  510,  510,
      510,  511,  511,  511,  425,  423,  511,  511,  512,  512,
      512,  512,  512,  512,  512,  512,  512,  512,  512,  512,
      512,  513,  513,  513,  513,  513,  513,  513,  513,  513,
      513,  513,  513,  513,  514,  422,  514,  421,  514,  420,
      514,  419,  514,  515,  515,  515,  515,  515,  515,  515,
      515,  515,  515,  515,  515,  515,  516,  417,  516,  416,
      516,  415,  516,  413,  516,  517,  517,  517,  517,  517,
      517,  517,  517,  518,  518,  518,  518,  518,  518,  518,
      518,  518,  518,  518,  518,  518,  519,  519,  519,  519,

      519,  519,  519,  519,  519,  519,  520,  412,  410,  409,
      408,  407,  406,  405,  520,  520,  520,  520,  521,  521,
      404,  521,  521,  521,  521,  521,  521,  521,  521,  521,
      521,  522,  522,  522,  522,  522,  522,  522,  522,  522,
      522,  522,  522,  522,  403,  400,  399,  396,  392,  391,
      389,  388,  387,  386,  385,  384,  383,  382,  381,  379,
      378,  377,  375,  374,  373,  372,  371,  369,  368,  367,
      366,  365,  364,  363,  362,  360,  359,  358,  357,  354,
      352,  351,  349,  348,  347,  346,  339,  338,  334,  333,
      332,  331,  330,  329,  328,  327,  326,  325,  324,  323,

      322,  321,  320,  319,  318,  317,  315,  312,  310,  309,
      307,  306,  305,  304,  303,  302,  300,  299,  298,  297,
      295,  294,  293,  292,  288,  287,  286,  285,  284,  283,
      282,  280,  279,  278,  277,  276,  275,  273,  267,  266,
      264,  263,  262,  260,  259,  258,  257,  256,  255,  254,
      253,  252,  251,  250,  249,  247,  245,  244,  241,  240,
      239,  238,  235,  232,  231,  230,  229,  228,  227,  226,
      225,  223,  222,  221,  220,  219,  218,  217,  216,  206,
      205,  204,  203,  202,  201,  200,  199,  198,  197,  196,
      195,  194,  193,  192,  191,  190,  189,  188,  186,  185,

      183,  182,  181,  180,  179,  178,  176,  175,  174,  173,
      172,  170,  169,  168,  167,  165,  164,  163,  162,  161,
      158,  157,  156,  153,  136,  135,  131,  128,  127,  124,
      122,  119,  118,  117,  116,  115,  114,  113,  112,  111,
      110,  109,  108,  107,  106,  105,  103,  102,   96,   92,
       77,   70,   63,   62,   60,   50,   49,   48,   47,   45,
       44,   42,   34,   32,   26,   23,   15,    7,    3,  505,
      505,  505,  505,  505,  505,  505,  505,  505,  505,  505,
      505,  505,  505,  505,  505,  505,  505,  505,  505,  505,
      505,  505,  505,  505,  505,  505,  505,  505,  505,  505,

      505,  505,  505,  505,  505,  505,  505,  505,  505,  505,
      505,  505,  505,  505,  505,  505,  505,  505,  505,  505,
      505,  505,  505,  505,  505,  505,  505,  505,  505,  505,
      505,  505,  505,  505,  505,  505,  505,  505,  505,  505,
      505,  505,  505,  505,  505,  505
    } ;

extern int yy_flex_debug;
int yy_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "scannerlexer.l"
/* -*- Mode: C -*-
 * GObject introspection: C lexer
 *
 * Copyright (c) 1997 Sandro Sigala  <ssigala@globalnet.it>
 * Copyright (c) 2007-2008 Jürg Billeter  <j@bitron.ch>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#line 31 "scannerlexer.l"
#include <ctype.h>
#include <stdio.h>
#include <stdlib.h>

#include "scanner.h"
#include "scannerparser.h"
#include "grealpath.h"

int lineno;
char linebuf[2000];

#undef YY_BUF_SIZE
#define YY_BUF_SIZE 1048576

extern int yylex (GIGenerator *igenerator);
#define YY_DECL int yylex (GIGenerator *igenerator)
#define yywrap() (1)
#define YY_SKIP_YYWRAP
static void parse_comment (GIGenerator *igenerator);
static void process_linemarks (GIGenerator *igenerator, gboolean has_line);
static int check_identifier (GIGenerator *igenerator, const char *);
static int parse_ignored_macro (void);
static void print_error (GIGenerator *igenerator);
#line 986 "scannerlexer.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * _in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * _out_str  );

			int yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	{
#line 65 "scannerlexer.l"


#line 1211 "scannerlexer.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 506 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 870 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
					{
					(yy_full_match) = yy_cp;
					break;
					}
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 67 "scannerlexer.l"
{ strncpy(linebuf, yytext+1, sizeof(linebuf)); /* save the next line */
						linebuf[sizeof(linebuf)-1]='\0';
						/* printf("%4d:%s\n",lineno,linebuf); */
						yyless(1);      /* give back all but the \n to rescan */
						++lineno;
					}
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 73 "scannerlexer.l"
{ ++lineno; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 75 "scannerlexer.l"
{ /* Ignore whitespace. */ }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 77 "scannerlexer.l"
{ parse_comment(igenerator); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 78 "scannerlexer.l"
{ /* Ignore C++ style comments. */ }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 80 "scannerlexer.l"
{ yyless (yyleng - 1); return FUNCTION_MACRO; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 81 "scannerlexer.l"
{ return OBJECT_MACRO; }
	YY_BREAK
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
#line 83 "scannerlexer.l"
{ process_linemarks(igenerator, FALSE); }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 84 "scannerlexer.l"
{ process_linemarks(igenerator, TRUE); }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 85 "scannerlexer.l"
{ }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 86 "scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 87 "scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 88 "scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 89 "scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 90 "scannerlexer.l"
{ return '['; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 91 "scannerlexer.l"
{ return '['; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 92 "scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 93 "scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 94 "scannerlexer.l"
{ return '('; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 95 "scannerlexer.l"
{ return ')'; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 96 "scannerlexer.l"
{ return ';'; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 97 "scannerlexer.l"
{ return ':'; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 98 "scannerlexer.l"
{ return ELLIPSIS; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 99 "scannerlexer.l"
{ return '?'; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 100 "scannerlexer.l"
{ return '.'; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 101 "scannerlexer.l"
{ return '+'; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 102 "scannerlexer.l"
{ return '-'; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 103 "scannerlexer.l"
{ return '*'; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 104 "scannerlexer.l"
{ return '/'; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 105 "scannerlexer.l"
{ return '%'; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 106 "scannerlexer.l"
{ return '^'; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 107 "scannerlexer.l"
{ return '&'; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 108 "scannerlexer.l"
{ return '|'; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 109 "scannerlexer.l"
{ return '~'; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 110 "scannerlexer.l"
{ return '!'; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 111 "scannerlexer.l"
{ return '='; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 112 "scannerlexer.l"
{ return '<'; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 113 "scannerlexer.l"
{ return '>'; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 114 "scannerlexer.l"
{ return ADDEQ; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 115 "scannerlexer.l"
{ return SUBEQ; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 116 "scannerlexer.l"
{ return MULEQ; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 117 "scannerlexer.l"
{ return DIVEQ; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 118 "scannerlexer.l"
{ return MODEQ; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 119 "scannerlexer.l"
{ return XOREQ; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 120 "scannerlexer.l"
{ return ANDEQ; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 121 "scannerlexer.l"
{ return OREQ; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 122 "scannerlexer.l"
{ return SL; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 123 "scannerlexer.l"
{ return SR; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 124 "scannerlexer.l"
{ return SLEQ; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 125 "scannerlexer.l"
{ return SREQ; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 126 "scannerlexer.l"
{ return EQ; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 127 "scannerlexer.l"
{ return NOTEQ; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 128 "scannerlexer.l"
{ return LTEQ; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 129 "scannerlexer.l"
{ return GTEQ; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 130 "scannerlexer.l"
{ return ANDAND; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 131 "scannerlexer.l"
{ return OROR; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 132 "scannerlexer.l"
{ return PLUSPLUS; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 133 "scannerlexer.l"
{ return MINUSMINUS; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 134 "scannerlexer.l"
{ return ','; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 135 "scannerlexer.l"
{ return ARROW; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 137 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 138 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 139 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 140 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 141 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 142 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 143 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 144 "scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 145 "scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 146 "scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 147 "scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 148 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 149 "scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 150 "scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 151 "scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 152 "scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 153 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 154 "scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 155 "scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 156 "scannerlexer.l"
{ return BOOL; }
	YY_BREAK
case 81:
/* rule 81 can match eol */
YY_RULE_SETUP
#line 157 "scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 158 "scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 159 "scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 160 "scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 161 "scannerlexer.l"
{ /* ignore */ }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 162 "scannerlexer.l"
{ /* ignore */ }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 163 "scannerlexer.l"
{ return INT; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 166 "scannerlexer.l"
{ if (igenerator->macro_scan) return check_identifier(igenerator, yytext); else REJECT; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 168 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 170 "scannerlexer.l"
{ return AUTO; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 171 "scannerlexer.l"
{ return BOOL; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 172 "scannerlexer.l"
{ return BREAK; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 173 "scannerlexer.l"
{ return CASE; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 174 "scannerlexer.l"
{ return CHAR; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 175 "scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 176 "scannerlexer.l"
{ return CONTINUE; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 177 "scannerlexer.l"
{ return DEFAULT; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 178 "scannerlexer.l"
{ return DO; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 179 "scannerlexer.l"
{ return DOUBLE; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 180 "scannerlexer.l"
{ return ELSE; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 181 "scannerlexer.l"
{ return ENUM; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 182 "scannerlexer.l"
{ return EXTERN; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 183 "scannerlexer.l"
{ return FLOAT; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 184 "scannerlexer.l"
{ return FOR; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 185 "scannerlexer.l"
{ return GOTO; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 186 "scannerlexer.l"
{ return IF; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 187 "scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 188 "scannerlexer.l"
{ return INT; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 189 "scannerlexer.l"
{ return INT; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 190 "scannerlexer.l"
{ return INT; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 191 "scannerlexer.l"
{ return INT; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 192 "scannerlexer.l"
{ return INT; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 193 "scannerlexer.l"
{ return LONG; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 194 "scannerlexer.l"
{ return REGISTER; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 195 "scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 196 "scannerlexer.l"
{ return RETURN; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 197 "scannerlexer.l"
{ return SHORT; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 198 "scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 199 "scannerlexer.l"
{ return SIZEOF; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 200 "scannerlexer.l"
{ return STATIC; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 201 "scannerlexer.l"
{ return STRUCT; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 202 "scannerlexer.l"
{ return SWITCH; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 203 "scannerlexer.l"
{ return TYPEDEF; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 204 "scannerlexer.l"
{ return UNION; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 205 "scannerlexer.l"
{ return UNSIGNED; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 206 "scannerlexer.l"
{ return VOID; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 207 "scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 208 "scannerlexer.l"
{ return WHILE; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 210 "scannerlexer.l"
{ return check_identifier(igenerator, yytext); }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 212 "scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 213 "scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 214 "scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 216 "scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 217 "scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 135:
/* rule 135 can match eol */
YY_RULE_SETUP
#line 219 "scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 136:
/* rule 136 can match eol */
YY_RULE_SETUP
#line 220 "scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 137:
/* rule 137 can match eol */
YY_RULE_SETUP
#line 222 "scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 138:
/* rule 138 can match eol */
YY_RULE_SETUP
#line 223 "scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 225 "scannerlexer.l"
{ print_error(igenerator); }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 227 "scannerlexer.l"
ECHO;
	YY_BREAK
#line 1985 "scannerlexer.c"
			case YY_STATE_EOF(INITIAL):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 506 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    
	YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 506 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
	yy_is_jam = (yy_current_state == 505);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = (yy_size_t)size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,(int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (yyconst char* msg )
{
			(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    yyfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 227 "scannerlexer.l"



static void parse_gtkdoc (GIGenerator *igenerator, int *c1, int *c2)
{
  gboolean isline = FALSE;
  gchar line[256];
  int i;
  gchar **parts;
  CDirective *directive;
  char *name, *value;

  i = 0;
  do {
      *c1 = *c2;
      if (*c1 == '\n')
	{
	  isline = TRUE;
	  break;
	}
      if (i >= 256)
	break;
      line[i++] = *c1;
      *c2 = input();

  } while (*c2 != EOF && !(*c1 == '*' && *c2 == '/'));
  
  if (!isline)
    return;

  line[i] = '\0';

  parts = g_strsplit (line, ": ", 2);

  if (g_strv_length (parts) == 2)
    {
      name = parts[0];
      value = parts[1];
    }
  else /* parts == 1 */
    {
      name = parts[0];
      value = NULL;
    }
  
  directive = cdirective_new (name, value);
  igenerator->directives = g_slist_prepend (igenerator->directives,
					    directive);

  g_strfreev (parts);
}

static void parse_comment (GIGenerator *igenerator)
{
  int c1, c2;
  
  c1 = input();
  c2 = input();

  while (c2 != EOF && !(c1 == '*' && c2 == '/'))
    {
      if (c1 == '\n')
	++lineno;
      c1 = c2;
      c2 = input();

      if (c1 == ' ' && c2 == '@')
	{
	  c1 = c2;
	  c2 = input();
	  parse_gtkdoc (igenerator, &c1, &c2);
	}
    }
}

static int
check_identifier (GIGenerator *igenerator,
		  const char *s)
{
	/*
	 * This function checks if `s' is a type name or an
	 * identifier.
	 */

	if (g_igenerator_is_typedef (igenerator, s)) {
		return TYPEDEF_NAME;
	} else if (strcmp (s, "__builtin_va_list") == 0) {
		return TYPEDEF_NAME;
	}

	return IDENTIFIER;
}

/*
 * # linenum "filename" flags
 *  See http://gcc.gnu.org/onlinedocs/cpp/Preprocessor-Output.html
 **/

static void
process_linemarks (GIGenerator *igenerator, gboolean has_line)
{
	char escaped_filename[1025];
	char *filename;
	char *real;

	if (has_line)
		sscanf(yytext, "#line %d \"%1024[^\"]\"", &lineno, escaped_filename);
	else
		sscanf(yytext, "# %d \"%1024[^\"]\"", &lineno, escaped_filename);

	filename = g_strcompress (escaped_filename);

        real = g_realpath (filename);
        if (real)
          {
            g_free (filename);
            filename = real;
          }

        if (igenerator->current_filename)
          g_free (igenerator->current_filename);
	igenerator->current_filename = filename;
}

/*
 * This parses a macro which is ignored, such as
 * __attribute__((x)) or __asm__ (x)
 */
static int
parse_ignored_macro (void)
{
	int c;
	int nest;

	while ((c = input ()) != EOF && isspace (c))
		;
	if (c != '(')
		return FALSE;

	nest = 0;
	while ((c = input ()) != EOF && (nest > 0 || c != ')')) {
		if (c == '(')
			nest++;
		else if (c == ')')
			nest--;
		else if (c == '"') {
			while ((c = input ()) != EOF && c != '"') {
				if (c == '\\')
					c = input ();
			}
		} else if (c == '\'') {
			c = input ();
			if (c == '\\')
				c = input ();
			else if (c == '\'')
				return FALSE;
			c = input ();
			if (c != '\'')
				return FALSE;
		} else if (c == '\n')
			lineno++;
	}

	return TRUE;
}

static void
print_error (GIGenerator *igenerator)
{
  if (yytext[0]) {
    fprintf(stderr, "%s:%d: unexpected character `%c'\n", igenerator->current_filename, lineno, yytext[0]);
  }
}

